@@ -16,14 +16,14 @@ class Stack():
 
     def add(self, element):
         if(self.size == self.length):
-            print("Stack is full")
+            print("Stack is full. Cannot add element ", element)
         else:
             self.elements.append(element)
             self.length += 1
 
     def remove(self):
         if(self.length == 0):
-            print("Stack is empty")
+            print("Stack is empty. Cannot remove an element.")
         else:
             elementToReturn = self.elements.pop()
             self.length -= 1
@@ -32,13 +32,13 @@ class Stack():
     def display(self):
         print(self.elements)
 
-    def getElements(self):
+    def get_elements(self):
         return self.elements
     
-    def getSize(self):
+    def get_size(self):
         return self.size
 
-    def getLength(self):
+    def get_length(self):
         return self.length
 
 
